==> netlify-cms-widget-uuid-0.0.4.tgz: package/src/UuidControl.js <==
import PropTypes from 'prop-types';
import React from 'react';
import Uuid4 from 'uuid/v4';
/** @jsx jsx */
import { css, jsx } from '@emotion/core';

const buttonStyle = {
  display: 'inline-block',
  'line-height': '1.5',
  padding: '19px',
  'border-radius': '0 5px 5px 0',
  width: '25%'
}

const inputStyle = {
  display: 'inline-block',
  'border-radius': '5px 0 0 5px',
  width: '75%'
}

export default class Control extends React.Component {
  static propTypes = {
    onChange: PropTypes.func.isRequired,
    forID: PropTypes.string,
    value: PropTypes.node,
    classNameWrapper: PropTypes.string.isRequired,
  }

  static defaultProps = {
    value: '',
  }

  handleClick = () => {
    const { onChange } = this.props;
    const value = Uuid4();
    onChange(value);
    console.log('bla');
    console.log('test', value);
  }

  render() {
    const {
      forID,
      value,
      onChange,
      classNameWrapper,
    } = this.props;

    return (
      <div>
        <input
        type="text"
        id={forID}
        className={classNameWrapper}
        value={value || ''}
        onChange={e => onChange(e.target.value)}
        css={css`
        display: inline-block;
        border-radius: 5px 0 0 5px;
        width: 75%
        `}
      />
      <button css={css`
        display: inline-block;
        line-height: 1.5;
        padding: 19px;
        border-radius: 0 5px 5px 0;
        width: 25%;
        &:hover {
        background-color: lightgrey;
        }
        `}
        onClick={this.handleClick}>Populate</button>
      </div>
    );
  }
}

==> netlify-cms-widget-uuid-0.0.7.tgz: package/src/UuidControl.js <==
import PropTypes from 'prop-types';
import React from 'react';
import Uuid4 from 'uuid/v4';
/** @jsx jsx */
import { css, jsx } from '@emotion/core';

const buttonStyle = {
  display: 'inline-block',
  'line-height': '1.5',
  padding: '19px',
  'border-radius': '0 5px 5px 0',
  width: '25%'
}

const inputStyle = {
  display: 'inline-block',
  'border-radius': '5px 0 0 5px',
  width: '75%'
}

export default class UUidControl extends React.Component {
  static propTypes = {
    onChange: PropTypes.func.isRequired,
    forID: PropTypes.string,
    value: PropTypes.node,
    classNameWrapper: PropTypes.string.isRequired,
  }

  static defaultProps = {
    value: '',
  }

  handleClick = () => {
    const { onChange } = this.props;
    const value = Uuid4();
    onChange(value);
  }

  render() {
    const {
      forID,
      value,
      onChange,
      classNameWrapper,
    } = this.props;

    return (
      <div>
        <input
        type="text"
        id={forID}
        className={classNameWrapper}
        value={value || ''}
        onChange={e => onChange(e.target.value)}
        css={css`
        display: inline-block;
        border-radius: 5px 0 0 5px;
        width: 75%
        `}
      />
      <button css={css`
        display: inline-block;
        line-height: 1.5;
        padding: 19px;
        border-radius: 0 5px 5px 0;
        width: 25%;
        &:hover {
        background-color: lightgrey;
        }
        `}
        onClick={this.handleClick}>Populate</button>
      </div>
    );
  }
}
